<template>
  <SettingsLayout :title="data.title">
    <form
      @submit.prevent="
        form.post(route('admin.settings.authorAssessment.configure.update'))
      "
    >
      <ActionToolBar :disable_save_button="form.processing" :toolbar="toolbar" />
      <h5>How it works</h5>
      <small class="text-muted">
        <ul>
          <li>The author registers</li>
          <li>
            After registration, they take an
            <Link :href="route('admin.settings.authorAssessment.mcq.index')"
              >MCQ test</Link
            >
            created by the admin, which must be completed within a set time.
          </li>
          <li>
            If they pass, they proceed to an
            <Link :href="route('admin.settings.authorAssessment.mcq.index')"
              >Essay test</Link
            >
            on a random topic from the admin’s list, which must be submitted within the
            given time.
          </li>
          <li>The admin receives a notification of the new application for review.</li>
        </ul>
      </small>
      <hr />
      <CheckBox
        v-model="form.enable_author_assessment"
        :label="__('Enable Author Assessment')"
        name="enable_author_assessment"
      />

      <Input
        v-model="form.total_mcq_questions"
        name="total_mcq_questions"
        :label="__('Total Multiple Choice Questions')"
      />

      <Input
        v-model="form.mcq_passing_score"
        name="mcq_passing_score"
        :label="__('MCQ Passing Score')"
        :tooltip="__('Each question carrying one point')"
      />

      <Input
        v-model="form.mcq_duration_in_minutes"
        name="mcq_duration_in_minutes"
        :label="__('MCQ Exam Duration in Minutes')"
      />

      <TextArea
        v-model="form.mcq_instructions"
        name="mcq_instructions"
        :label="__('MCQ Instructions')"
      />

      <TextArea
        v-model="form.message_after_failing_the_assessment"
        name="message_after_failing_the_assessment"
        :label="__('Message to display if the applicant fails the MCQ Exam')"
      />

      <Input
        v-model="form.text_submission_deadline_in_hours"
        name="text_submission_deadline_in_hours"
        :label="__('Writing Test Duration in Hours')"
      />

      <Input
        v-model="form.text_word_minimum_limit"
        name="text_word_minimum_limit"
        :label="__('Minimum Number of Words for Writing Test')"
      />

      <Input
        v-model="form.text_word_maximum_limit"
        name="text_word_maximum_limit"
        :label="__('Maximum Number of Words for Writing Test')"
      />

      <TextArea
        v-model="form.message_after_essay_submission"
        name="message_after_essay_submission"
        :label="__('Message to display after submission of the writing by the applicant')"
      />
    </form>
  </SettingsLayout>
</template>

<script>
import SettingsLayout from "../Partials/SettingsLayout.vue";
import ActionToolBar from "../Partials/ActionToolBar.vue";
import { Input, TextArea, CheckBox } from "../../../../components/Form/Index.js";

export default {
  components: {
    SettingsLayout,
    ActionToolBar,
    Input,
    TextArea,
    CheckBox,
  },
  props: ["data", "records"],
  data() {
    return {
      form: this.$inertia.form(this.records),
      toolbar: {
        title: this.data.title,
      },
    };
  },
};
</script>
